Polygon
=======

.. currentmodule:: pywwt

.. autoclass:: Polygon
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Polygon.fill
      ~Polygon.fill_color
      ~Polygon.line_color
      ~Polygon.line_width
      ~Polygon.shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~Polygon.add_point

   .. rubric:: Attributes Documentation

   .. autoattribute:: fill
   .. autoattribute:: fill_color
   .. autoattribute:: line_color
   .. autoattribute:: line_width
   .. autoattribute:: shape

   .. rubric:: Methods Documentation

   .. automethod:: add_point
